@@ -16,6 +16,9 @@ Failures will result in a die.
 
 use strict;
 package Devel::CoverX::Covered::Db;
+{
+  $Devel::CoverX::Covered::Db::VERSION = '0.013';
+}
 use Moose;
 
 use Devel::Cover::DB;
@@ -25,7 +28,7 @@ use DBIx::Simple;
 use DBD::SQLite;
 use File::Path;
 use File::chdir;
-use Path::Class;
+use Path::Class qw/ file /;
 use Memoize;
 
 
@@ -265,7 +268,7 @@ sub collect_runs {
         for my $run_db_dir ($self->get_run_dirs()) {
             my $cover_db = Devel::Cover::DB->new(db => $self->dir);
 
-            my $run_db_file = "$run_db_dir/cover.12";  #Eeh, refactor
+            my $run_db_file = "$run_db_dir/cover.13";  #Eeh, refactor
             -e $run_db_file or warn("No run db ($run_db_file)\n"), next;
             $cover_db->read($run_db_file);
 
